@@ -150,6 +150,7 @@ extern int Assemble(char *mddev, int mdfd,
 		    char *conffile,
 		    mddev_dev_t devlist,
 		    int readonly, int runstop,
+		    char *update,
 		    int verbose, int force);
 
 extern int Build(char *mddev, int mdfd, int chunk, int level,
@@ -167,7 +168,7 @@ extern int Query(char *dev);
 extern int Examine(mddev_dev_t devlist, int brief, int scan, int SparcAdjust);
 extern int Monitor(mddev_dev_t devlist,
 		   char *mailaddr, char *alert_cmd,
-		   int period, int scan,
+		   int period, int daemonise, int scan,
 		   char *config);
 
 extern int Kill(char *dev, int force);
